@@ -9,8 +9,7 @@ from subprocess import run, DEVNULL
 class MsgfmtCmdBuildHook(BuildHookBase):
     PLUGIN_NAME = 'msgfmtcmd'
 
-    @staticmethod
-    def convert(input: Path) -> bytes:
+    def convert(self, input: Path) -> bytes:
         with NamedTemporaryFile('rb', suffix='.mo') as file:
             run(['msgfmt', '-o', file.name, str(input)], check=True, stdin=DEVNULL)
             return file.read()
